#
# spec file for package hdf5
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define hdf5_libver 0
%define libname libhdf5

%if 0%{?sles_version}
%define _mvapich2 1
%endif
%if 0%{?suse_version}
%define _openmpi 1
%endif

%define _mpi %{?_openmpi:openmpi} %{?_mvapich2:mvapich2}

# rpm may not like this original version number
%define xversion 1.8.10-patch1

Name:           hdf5
Version:        1.8.10.patch1
Release:        51.1
Summary:        A general purpose library and file format for storing scientific data
License:        BSD-3-Clause
Group:          Development/Libraries/Other
Url:            http://www.hdfgroup.org/HDF5/
Source0:        http://www.hdfgroup.org/ftp/HDF5/releases/hdf5-%{xversion}/src/hdf5-%{xversion}.tar.bz2
Patch0:         hdf5-LD_LIBRARY_PATH.patch
Patch1:         hdf5-non_void_return.patch
# fix broken printf call, sent upstream
Patch2:         hdf5-fix_printf.patch
%ifarch %arm
Patch4:         hdf5-1.8.10-tests-arm.patch
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++
%if 0%{?suse_version} > 1140
BuildRequires:  gcc-fortran
%endif
BuildRequires:  krb5-devel
BuildRequires:  openssl-devel
BuildRequires:  zlib-devel
%if 0%{?suse_version} >= 1110
BuildRequires:  fdupes
%endif
%if 0%{?_openmpi}
BuildRequires:  openmpi-devel
%endif
%if 0%{?_mvapich2}
BuildRequires:  mvapich2-devel
%endif

%description
HDF5 is a general purpose library and file format for storing scientific data.
HDF5 can store two primary objects: datasets and groups. A dataset is
essentially a multidimensional array of data elements, and a group is a
structure for organizing objects in an HDF5 file. Using these two basic
objects, one can create and store almost any kind of scientific data
structure, such as images, arrays of vectors, and structured and unstructured
grids. You can also mix and match them in HDF5 files according to your needs.

%package -n %{libname}-%{hdf5_libver}
Summary:        HDF 5 runtime libraries
Group:          System/Libraries

%description -n %{libname}-%{hdf5_libver}
The HDF project involves the development and support of software and
file formats for scientific data management. The HDF software includes
I/O libraries and tools for analyzing, visualizing, and converting
scientific data.

This package contains the HDF 5 runtime libraries.

%package -n %{libname}_hl%{hdf5_libver}
Summary:        HDF 5 runtimelibraries
Group:          System/Libraries

%description -n %{libname}_hl%{hdf5_libver}
The HDF project involves the development and support of software and
file formats for scientific data management. The HDF software includes
I/O libraries and tools for analyzing, visualizing, and converting
scientific data.

This package contains the HDF 5 runtime libraries.

%package devel
Summary:        Hierarchical Data File Format Version 5
Group:          Development/Libraries/Parallel
Requires:       %{name} = %{version}
# Required by Fortran programs?
Requires:       %{libname}-%{hdf5_libver} = %{version}
Requires:       %{libname}_hl%{hdf5_libver} = %{version}

%description devel
The HDF project involves the development and support of software and
file formats for scientific data management. The HDF software includes
I/O libraries and tools for analyzing, visualizing, and converting
scientific data.

This package contains all files needed to create projects that use
hdf5.

%package  devel-static
Summary:        Hierarchical Data File Format Version 5 - static libraries
Group:          Development/Libraries/C and C++
Requires:       hdf5-devel

%description devel-static
The HDF project involves the development and support of software and
file formats for scientific data management. The HDF software includes
I/O libraries and tools for analyzing, visualizing, and converting
scientific data.

This package provides the static libraries.

%package examples
Summary:        Examples for HDF5
Group:          Development/Libraries/Parallel
Requires:       %{libname}-%{hdf5_libver} = %{version}
Requires:       %{libname}_hl%{hdf5_libver} = %{version}

%description examples
Examples of HDF5 library use.


%if 0%{?_openmpi}
%package -n %{name}-openmpi
Summary:        A general purpose library and file format for storing scientific data
Group:          Development/Libraries/Other

%description -n %{name}-openmpi
HDF5 is a general purpose library and file format for storing scientific data.
HDF5 can store two primary objects: datasets and groups. A dataset is
essentially a multidimensional array of data elements, and a group is a
structure for organizing objects in an HDF5 file. Using these two basic
objects, one can create and store almost any kind of scientific data
structure, such as images, arrays of vectors, and structured and unstructured
grids. You can also mix and match them in HDF5 files according to your needs.

%package -n %{libname}-%{hdf5_libver}-openmpi
Summary:        HDF 5 runtime libraries
Group:          System/Libraries

%description -n %{libname}-%{hdf5_libver}-openmpi
The HDF project involves the development and support of software and
file formats for scientific data management. The HDF software includes
I/O libraries and tools for analyzing, visualizing, and converting
scientific data.

This package contains the HDF 5 runtime libraries.

%package -n %{libname}_hl%{hdf5_libver}-openmpi
Summary:        HDF 5 runtimelibraries
Group:          System/Libraries

%description -n %{libname}_hl%{hdf5_libver}-openmpi
The HDF project involves the development and support of software and
file formats for scientific data management. The HDF software includes
I/O libraries and tools for analyzing, visualizing, and converting
scientific data.

This package contains the HDF 5 runtime libraries.

%package openmpi-devel
Summary:        Hierarchical Data File Format Version 5
Group:          Development/Libraries/Parallel
Requires:       %{name}-openmpi = %{version}
# Required by Fortran programs?
Requires:       %{libname}-%{hdf5_libver}-openmpi = %{version}
Requires:       %{libname}_hl%{hdf5_libver}-openmpi = %{version}

%description openmpi-devel
The HDF project involves the development and support of software and
file formats for scientific data management. The HDF software includes
I/O libraries and tools for analyzing, visualizing, and converting
scientific data.

This package contains all files needed to create projects that use
hdf5.

%package  openmpi-devel-static
Summary:        Hierarchical Data File Format Version 5 - static libraries
Group:          Development/Libraries/C and C++
Requires:       hdf5-openmpi-devel

%description openmpi-devel-static
The HDF project involves the development and support of software and
file formats for scientific data management. The HDF software includes
I/O libraries and tools for analyzing, visualizing, and converting
scientific data.

This package provides the static libraries.
%endif

%if 0%{?_mvapich2}
%package -n %{name}-mvapich2
Summary:        A general purpose library and file format for storing scientific data
Group:          Development/Libraries/Other

%description -n %{name}-mvapich2
HDF5 is a general purpose library and file format for storing scientific data.
HDF5 can store two primary objects: datasets and groups. A dataset is
essentially a multidimensional array of data elements, and a group is a
structure for organizing objects in an HDF5 file. Using these two basic
objects, one can create and store almost any kind of scientific data
structure, such as images, arrays of vectors, and structured and unstructured
grids. You can also mix and match them in HDF5 files according to your needs.

%package -n %{libname}-%{hdf5_libver}-mvapich2
Summary:        HDF 5 runtime libraries
Group:          System/Libraries

%description -n %{libname}-%{hdf5_libver}-mvapich2
The HDF project involves the development and support of software and
file formats for scientific data management. The HDF software includes
I/O libraries and tools for analyzing, visualizing, and converting
scientific data.

This package contains the HDF 5 runtime libraries.

%package -n %{libname}_hl%{hdf5_libver}-mvapich2
Summary:        HDF 5 runtimelibraries
Group:          System/Libraries

%description -n %{libname}_hl%{hdf5_libver}-mvapich2
The HDF project involves the development and support of software and
file formats for scientific data management. The HDF software includes
I/O libraries and tools for analyzing, visualizing, and converting
scientific data.

This package contains the HDF 5 runtime libraries.

%package mvapich2-devel
Summary:        Hierarchical Data File Format Version 5
Group:          Development/Libraries/Parallel
Requires:       %{name}-mvapich2 = %{version}
# Required by Fortran programs?
Requires:       %{libname}-%{hdf5_libver}-mvapich2 = %{version}
Requires:       %{libname}_hl%{hdf5_libver}-mvapich2 = %{version}

%description mvapich2-devel
The HDF project involves the development and support of software and
file formats for scientific data management. The HDF software includes
I/O libraries and tools for analyzing, visualizing, and converting
scientific data.

This package contains all files needed to create projects that use
hdf5.

%package  mvapich2-devel-static
Summary:        Hierarchical Data File Format Version 5 - static libraries
Group:          Development/Libraries/C and C++
Requires:       hdf5-mvapich2-devel

%description mvapich2-devel-static
The HDF project involves the development and support of software and
file formats for scientific data management. The HDF software includes
I/O libraries and tools for analyzing, visualizing, and converting
scientific data.

This package provides the static libraries.
%endif

%prep
%setup -q -n %{name}-%{xversion}
%patch0 -p1 -b .LD_LIBRARY_PATH
%patch1 -p0 -b .non_void_return
%patch2 -p0 -b .fix_printf
%ifarch %arm
%patch4 -p0 -b .tests-arm
%endif

echo "prepare parallel builds: %_mpi"
for build_dir in build %_mpi; do
    mkdir $build_dir
    ln -s ../configure $build_dir
done

%build
export CC=gcc
export CXX=g++
export F9X=gfortran
export CFLAGS="${RPM_OPT_FLAGS/-O2/-O0}"
# export CFLAGS="%%{optflags} -fno-strict-aliasing"

pushd build
%configure \
  --docdir=%{_docdir}/%{name} \
  --disable-dependency-tracking \
%if 0%{?suse_version} > 1140
  --enable-fortran \
%endif
  --enable-hl \
  --enable-shared \
  --enable-cxx \
  --with-pthread

make %{?_smp_mflags}
popd

for mpi in %_mpi;
do
cd $mpi
export CC="%{_libdir}/mpi/gcc/$mpi/bin/mpicc"
export FC="%{_libdir}/mpi/gcc/$mpi/bin/mpif90"
export F77="%{_libdir}/mpi/gcc/$mpi/bin/mpif77"
export LD_LIBRARY_PATH="%{_libdir}/mpi/gcc/$mpi/%_lib"
%configure \
  --docdir=%{_docdir}/%{name} \
  --prefix=%{_libdir}/mpi/gcc/$mpi \
  --exec-prefix=%{_libdir}/mpi/gcc/$mpi \
  --bindir=%{_libdir}/mpi/gcc/$mpi/bin \
  --libdir=%{_libdir}/mpi/gcc/$mpi/%_lib \
  --datadir=%{_libdir}/mpi/gcc/$mpi/share \
  --includedir=%{_libdir}/mpi/gcc/$mpi/include \
  --disable-dependency-tracking \
%if 0%{?suse_version} > 1140
  --enable-fortran \
%endif
  --enable-hl \
  --enable-shared \
  --enable-parallel \
  --with-pthread

make %{?_smp_mflags}
cd ..
done

%install
# install serial and parallel builds, (the serial one will win in case of
# duplicate files)
for build_dir in %_mpi build; do
	make install DESTDIR="%buildroot" -C "$build_dir"
done

find "%buildroot/%_libdir" -type f -name "*.la" | xargs rm -f
find %{buildroot}%{_datadir}/hdf5_examples -type f \
                 | grep -v ".sh$" | xargs chmod 644
# delete examples from parallel builds
rm -rf %{buildroot}%{_libdir}/mpi/gcc/*/share/hdf5_examples
%if 0%{?suse_version} >= 1110
%fdupes -s %{buildroot}/%{_datadir}
%endif

# rpm macro for version checking
mkdir -p %{buildroot}%{_sysconfdir}/rpm
cat > %{buildroot}%{_sysconfdir}/rpm/macros.hdf5 <<EOF
#
# RPM macros for R packaging
#

#
# Make R search index.txt
#
%_hdf5_version  %{version}
EOF

%check
make -C build check
# ignore errors for parallel builds
export HDF5_Make_Ignore=yes
for mpi in %_mpi; do
    make -C $mpi check
done

%post -n %{libname}-%{hdf5_libver} -p /sbin/ldconfig

%postun -n %{libname}-%{hdf5_libver} -p /sbin/ldconfig

%post -n %{libname}_hl%{hdf5_libver} -p /sbin/ldconfig

%postun -n %{libname}_hl%{hdf5_libver} -p /sbin/ldconfig

%if 0%{?_openmpi}
%post -n %{libname}-%{hdf5_libver}-openmpi -p /sbin/ldconfig

%postun -n %{libname}-%{hdf5_libver}-openmpi -p /sbin/ldconfig

%post -n %{libname}_hl%{hdf5_libver}-openmpi -p /sbin/ldconfig

%postun -n %{libname}_hl%{hdf5_libver}-openmpi -p /sbin/ldconfig
%endif

%if 0%{?_mvapich2}
%post -n %{libname}-%{hdf5_libver}-mvapich2 -p /sbin/ldconfig

%postun -n %{libname}-%{hdf5_libver}-mvapich2 -p /sbin/ldconfig

%post -n %{libname}_hl%{hdf5_libver}-mvapich2 -p /sbin/ldconfig

%postun -n %{libname}_hl%{hdf5_libver}-mvapich2 -p /sbin/ldconfig
%endif

%files
%defattr(-,root,root)
%doc COPYING MANIFEST README.txt release_docs/RELEASE.txt
%doc release_docs/HISTORY-1_0-1_8_0_rc3.txt release_docs/HISTORY-1_8.txt
%doc release_docs/RELEASE.txt
%{_bindir}/gif2h5
%{_bindir}/h52gif
%{_bindir}/h5copy
%{_bindir}/h5debug
%{_bindir}/h5diff
%{_bindir}/h5dump
%{_bindir}/h5import
%{_bindir}/h5jam
%{_bindir}/h5ls
%{_bindir}/h5mkgrp
%{_bindir}/h5perf_serial
%{_bindir}/h5redeploy
%{_bindir}/h5repack
%{_bindir}/h5repart
%{_bindir}/h5stat
%{_bindir}/h5unjam

%files -n %{libname}-%{hdf5_libver}
%defattr(0755,root,root)
%{_libdir}/libhdf5.so.*
%{_libdir}/libhdf5_cpp.so.*
%if 0%{?suse_version} > 1140
%{_libdir}/libhdf5_fortran.so.*
%endif

%files -n libhdf5_hl%{hdf5_libver}
%defattr(0755,root,root)
%{_libdir}/libhdf5_hl.so.*
%{_libdir}/libhdf5_hl_cpp.so.*
%if 0%{?suse_version} > 1140
%{_libdir}/libhdf5hl_fortran.so.*
%endif

%files devel
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/rpm/macros.hdf5
%{_bindir}/h5c++
%{_bindir}/h5cc
%if 0%{?suse_version} > 1140
%{_bindir}/h5fc
%endif
%{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/*.settings
%if 0%{?suse_version} > 1140
%{_includedir}/*.mod
%endif

%files devel-static
%defattr(-,root,root)
%{_libdir}/*.a

%files examples
%defattr(-,root,root)
%{_datadir}/hdf5_examples

%if 0%{?_openmpi}
%files -n %{name}-openmpi
%defattr(-,root,root)
%doc COPYING MANIFEST README.txt release_docs/RELEASE.txt
%doc release_docs/HISTORY-1_0-1_8_0_rc3.txt release_docs/HISTORY-1_8.txt
%doc release_docs/RELEASE.txt
%{_libdir}/mpi/gcc/openmpi/bin/gif2h5
%{_libdir}/mpi/gcc/openmpi/bin/h52gif
%{_libdir}/mpi/gcc/openmpi/bin/h5copy
%{_libdir}/mpi/gcc/openmpi/bin/h5debug
%{_libdir}/mpi/gcc/openmpi/bin/h5diff
%{_libdir}/mpi/gcc/openmpi/bin/h5dump
%{_libdir}/mpi/gcc/openmpi/bin/h5import
%{_libdir}/mpi/gcc/openmpi/bin/h5jam
%{_libdir}/mpi/gcc/openmpi/bin/h5ls
%{_libdir}/mpi/gcc/openmpi/bin/h5mkgrp
%{_libdir}/mpi/gcc/openmpi/bin/h5perf
%{_libdir}/mpi/gcc/openmpi/bin/h5perf_serial
%{_libdir}/mpi/gcc/openmpi/bin/h5redeploy
%{_libdir}/mpi/gcc/openmpi/bin/h5repack
%{_libdir}/mpi/gcc/openmpi/bin/h5repart
%{_libdir}/mpi/gcc/openmpi/bin/h5stat
%{_libdir}/mpi/gcc/openmpi/bin/h5unjam
%{_libdir}/mpi/gcc/openmpi/bin/ph5diff

%files -n %{libname}-%{hdf5_libver}-openmpi
%defattr(0755,root,root)
%{_libdir}/mpi/gcc/openmpi/%_lib/libhdf5.so.*
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/openmpi/%_lib/libhdf5_fortran.so.*
%endif

%files -n libhdf5_hl%{hdf5_libver}-openmpi
%defattr(0755,root,root)
%{_libdir}/mpi/gcc/openmpi/%_lib/libhdf5_hl.so.*
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/openmpi/%_lib/libhdf5hl_fortran.so.*
%endif

%files openmpi-devel
%defattr(-,root,root)
%{_libdir}/mpi/gcc/openmpi/bin/h5pcc
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/openmpi/bin/h5pfc
%endif
%{_libdir}/mpi/gcc/openmpi/include/*.h
%{_libdir}/mpi/gcc/openmpi/%_lib/*.so
%{_libdir}/mpi/gcc/openmpi/%_lib/*.settings
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/openmpi/include/*.mod
%endif

%files openmpi-devel-static
%defattr(-,root,root)
%{_libdir}/mpi/gcc/openmpi/%_lib/*.a
%endif

%if 0%{?_mvapich2}
%files -n %{name}-mvapich2
%defattr(-,root,root)
%doc COPYING MANIFEST README.txt release_docs/RELEASE.txt
%doc release_docs/HISTORY-1_0-1_8_0_rc3.txt release_docs/HISTORY-1_8.txt
%doc release_docs/RELEASE.txt
%{_libdir}/mpi/gcc/mvapich2/bin/gif2h5
%{_libdir}/mpi/gcc/mvapich2/bin/h52gif
%{_libdir}/mpi/gcc/mvapich2/bin/h5copy
%{_libdir}/mpi/gcc/mvapich2/bin/h5debug
%{_libdir}/mpi/gcc/mvapich2/bin/h5diff
%{_libdir}/mpi/gcc/mvapich2/bin/h5dump
%{_libdir}/mpi/gcc/mvapich2/bin/h5import
%{_libdir}/mpi/gcc/mvapich2/bin/h5jam
%{_libdir}/mpi/gcc/mvapich2/bin/h5ls
%{_libdir}/mpi/gcc/mvapich2/bin/h5mkgrp
%{_libdir}/mpi/gcc/mvapich2/bin/h5perf
%{_libdir}/mpi/gcc/mvapich2/bin/h5perf_serial
%{_libdir}/mpi/gcc/mvapich2/bin/h5redeploy
%{_libdir}/mpi/gcc/mvapich2/bin/h5repack
%{_libdir}/mpi/gcc/mvapich2/bin/h5repart
%{_libdir}/mpi/gcc/mvapich2/bin/h5stat
%{_libdir}/mpi/gcc/mvapich2/bin/h5unjam
%{_libdir}/mpi/gcc/mvapich2/bin/ph5diff

%files -n %{libname}-%{hdf5_libver}-mvapich2
%defattr(0755,root,root)
%{_libdir}/mpi/gcc/mvapich2/%_lib/libhdf5.so.*
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/mvapich2/%_lib/libhdf5_fortran.so.*
%endif

%files -n libhdf5_hl%{hdf5_libver}-mvapich2
%defattr(0755,root,root)
%{_libdir}/mpi/gcc/mvapich2/%_lib/libhdf5_hl.so.*
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/mvapich2/%_lib/libhdf5hl_fortran.so.*
%endif

%files mvapich2-devel
%defattr(-,root,root)
%{_libdir}/mpi/gcc/mvapich2/bin/h5pcc
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/mvapich2/bin/h5pfc
%endif
%{_libdir}/mpi/gcc/mvapich2/include/*.h
%{_libdir}/mpi/gcc/mvapich2/%_lib/*.so
%{_libdir}/mpi/gcc/mvapich2/%_lib/*.settings
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/mvapich2/include/*.mod
%endif

%files mvapich2-devel-static
%defattr(-,root,root)
%{_libdir}/mpi/gcc/mvapich2/%_lib/*.a
%endif

%changelog
* Fri Apr 12 2013 sweet_f_a@gmx.de
- Update to 1.8.10-patch1:
  * official important bug fixes for 1.8.10
  * see RELEASE.txt "Bug Fixes since HDF5-1.8.10"
* Sun Nov 18 2012 sweet_f_a@gmx.de
- Update to 1.8.10, changes documented here:
  http://www.hdfgroup.org/HDF5/doc/ADGuide/Changes.html
- remove hdf5-ph5diff.patch (fixed by upstream)
- add hdf5-fix_printf.patch
* Fri Nov 16 2012 sweet_f_a@gmx.de
- cosmetics, enable parallel build for suse only
- fix build for old findutils
* Mon Nov  5 2012 coolo@suse.com
- fixing baselibs.conf
* Wed Sep 26 2012 sweet_f_a@gmx.de
- make sure to install the examples from non-parallel build
* Mon Sep 24 2012 sweet_f_a@gmx.de
- don't use deprecated macro makeinstall
- enable test suite for parallel builds
- always build out of tree instead of copying sources
* Fri Sep  7 2012 scorot@free.fr
- parallel versions for openmpi and mvapich2
- add baselibs.conf
* Wed Jun 20 2012 sweet_f_a@gmx.de
- minor rpm portability build fixes
  - remove unused source file h5comp
  - enable all tests on ppc again (remove hdf5-1.8.8-tstlite.patch)
  - build fixes for arm
  * avoid some false positives "no-return-in-nonvoid-function"
  * disable some tests on arm only (hdf5-1.8.9-tests-arm.patch)
* Mon May 28 2012 ocefpaf@gmail.com
- Update to 1.8.9
  * Changes documented here:
  http://www.hdfgroup.org/HDF5/doc/ADGuide/Changes.html
* Mon Mar 12 2012 sweet_f_a@gmx.de
- install libhdf5.settings (bnc#751747)
- move executables h5cc and h5c++ to the devel package
* Sun Feb 19 2012 ocefpaf@gmail.com
- Removed "Fixup headers and scripts for multiarch".
* Wed Nov 30 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Accurate rpmgroup selection for shared library packages
* Tue Nov 29 2011 ocefpaf@gmail.com
- un-commented --with-pthread and --with-ssl.
* Mon Nov 28 2011 ocefpaf@gmail.com
- Update to 1.8.8
  * Add patch to avoid setting LD_LIBRARY_PATH
  * Add patch hdf5-non_void_return.patch
  * Fixed non_void_return (thanks to Boris Manojlovic).
  * Drop tstlite patch
  * drop ppc64 longdouble patch, not required anymore
  * Catch up with some Fedora modifications
  - Add rpm macro %%%%{_hdf5_version} for convenience
  * No Fortran modules for opensuse < 11.4 (Do not pass make check)
  New Features
  ============
    Configuration
  - ------------
  - Added the --enable-fortran2003 flag to enable Fortran2003 support
    in the HDF5 Fortran library. The flag should be used along with the
  - -enable-fortran flag and takes affect only when the Fortran compiler
    is Fortran2003 compliant. (EIP - 2011/11/14)
  - Added checks for clock_gettime and mach/mach_time.h to both configure and
    CMake.  This will support the move from gettimeofday to clock_gettime's
    monotonic timer in the profiling code in a future release.
    (DER - 2011/10/12)
    Library
  - ------
  - The Windows VFD code has been removed with the exception of the functions
    which set it (H5Pset_fapl_windows, for example).  Setting the Windows
    VFD now really sets the SEC2 VFD.  The WINDOWS_MAX_BUF and
    WINDOWS_USE_STDIO configuration options and #defines have also been
    removed. NOTE: Since the Windows VFD was a clone of the SEC2 VFD, this
    change should be transparent to users.
    (DER - 2011/10/12 - HDFFV-7740, HDFFV-7744)
  - H5Tcreate now supports the string type (fixed-length and variable-
    length). (SLU - 2011/05/20)
    Parallel Library
  - ---------------
  - Added new H5Pget_mpio_actual_chunk_opt_mode and
    H5Pget_mpio_actual_io_mode API routines for querying whether/how
    a collective I/O operation completed.  (QAK - 2011/10/12)
    Tools
  - ----
  - None
    High-Level APIs
  - --------------
  - Added the following Fortran wrappers for the Dimension Scale APIs:
    h5dsset_scale_f
    h5dsattach_scale_f
    h5dsdetach_scale_f
    h5dsis_attached_f
    h5dsis_scale_f
    h5dsset_label_f
    h5dsget_label_f
    h5dsget_scale_name_f
    h5dsget_num_scales_f
    (EIP for SB - 2011/10/13 - HDFFV-3797)
    Fortran API
  - ----------
  - The HDF5 Fortran library was enhanced to support the Fortran 2003 standard.
    The following features are available when the HDF5 library is configured
    using the --enable-fortran and --enable-fortran2003 configure flags AND
    if the Fortran compiler is Fortran 2003 compliant:
  - Subroutines overloaded with the C_PTR derived type:
    h5pget_f
    h5pget_fill_value_f
    h5pinsert_f
    h5pregister_f
    h5pset_f
    h5pset_fill_value_f
    h5rcreate_f
    h5rderefrence_f
    h5rget_name_f
    h5rget_obj_type_f
  - Subroutines overloaded with the C_PTR derived type
    and simplified signatures:
    h5aread_f
    h5awrite_f
    h5dread_f
    h5dwrite_f
  - New subroutines
    h5dvlen_reclaim_f
    h5literate_by_name_f
    h5literate_f
    h5ovisit_f
    h5tconvert_f
    h5pset_nbit_f
    h5pset_scaleoffset_f
  - Subroutines with additional optional parameters:
    h5pcreate_class_f
    (EIP - 2011/10/14)
    C++ API
  - ------
  - None
* Thu Jun  2 2011 ocefpaf@yahoo.com.br
- uncomment make check
* Tue May 24 2011 pgajdos@novell.com
- updated to 1.8.7
* Fri Apr 29 2011 pth@suse.de
- undrop package.
- Do type-punning using unions to be able to compile without
  - fno-strict-aliasing.
- Don't use macros in patch names.
- Use _cv_ in variables to be cached by configure.
* Thu May  7 2009 pgajdos@suse.cz
- fixed build with new gcc, see [bnc#501751]
* Mon Mar  2 2009 crrodriguez@suse.de
- save 9MB removing static libraries
* Tue Jan 13 2009 pgajdos@suse.cz
- updated to 1.8.2:
  - Upgraded libtool to version 2.2.6a. (MAM - 2008/10/15).
  - Added two new public routines: H5Pget_elink_fapl() and
    H5Pset_elink_fapl(). (see bug #1247) (VC - 2008/10/13)
  - Improved free space tracking in file to be faster. (QAK - 2008/10/06)
  - Added 'mounted' field to H5G_info_t struct. (QAK - 2008/07/15)
  - h5repack: added new options -u and -b to add a userblock to an HDF5
    file during the repack.  (PVN - 2008/08/26)
  - h5repack: added options -t and -a to call H5Pset_alignment while
    creating a repacked file. (PVN - 2008/08/29)
  - h5ls: added capability to traverse through external links when the -r
    (recursive) flag is given. (NAF - 2008/09/16)
  - h5ls: added -E option to enable traversal of external links.
    h5ls will not traverse external links without this flag being set.
    (NAF - 2008/10/06)
  - h5dump: when -b flag is used without a keyword after it, binary
    output defaults to NATIVE. MEMORY keyword was deprecated
    and replaced by NATIVE keyword. (PVN - 2008/10/30)
  - h5diff: returns 1 when file graphs differ by any object.
    Error return code was changed to 2 from -1.  (PVN - 2008/10/30)
  - h5import: TEXTFPE (scientific format) was deprecated. Use TEXTFP
    instead (PVN - 2008/10/30)
  - Added optional parameter 'mounted' to H5Gget_info_f,
    H5Gget_info_by_idx_f, H5Gget_info_by_name_f (MSB - 2008/09/24)
  - Added H5Tget_native_type_f (MSB - 2008/09/30)
  - These member functions were added as wrapper for H5Rdereference to
    replace the incorrect IdComponent::dereference().
    void H5Object::dereference(H5Object& obj, void* ref,
    H5R_type_t ref_type=H5R_OBJECT)
    void H5Object::dereference(H5File& h5file, void* ref,
    H5R_type_t ref_type=H5R_OBJECT)
    void H5Object::dereference(Attribute& obj, void* ref,
    H5R_type_t ref_type=H5R_OBJECT)
    In addition, these constructors were added to create the associated
    objects by way of dereference:
    DataSet(H5Object& obj, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    DataSet(H5File& file, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    DataSet(Attribute& attr, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    Group(H5Object& obj, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    Group(H5File& obj, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    Group(Attribute& attr, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    DataType(H5Object& obj, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    DataType(H5File& file, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    DataType(Attribute& attr, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    (BMR - 2008/10/29)
- removed destdir.patch
* Mon Jan 12 2009 pgajdos@suse.cz
- fortran modules builds from now [bnc#457593]
* Tue Nov 11 2008 pgajdos@suse.cz
- fixing build of fortran interface moved to the future
* Wed Jul  2 2008 pgajdos@suse.cz
- updated to 1.8.1 [bnc#401626]
  * Enhanced group object management
  * Enhanced attribute management and more efficient meta data handling
  * Expanded datatype features
  * Creation order tracking and indexing
  * Improved meta data caching and cache control
  * UTF-8 encoding
  * New I/O filters: n-bit and scale+offset compression
  * New link (H5L) and object (H5O) interfaces and features
  * External and user-defined links
  * New high-level APIs:
    HDF5 Packet Table (H5PT) and HDF5 Dimension Scale (H5DS)
  * C++ and Fortran interfaces for older high-level APIs:
    H5Lite (H5LT), H5Image (H5IM), and H5Table (H5TB)
  * New and improved tools
- removed doc package (doc/html no longer provided with package)
- octave builds againist 1.6 compatibility stuff
* Wed May  7 2008 pgajdos@suse.cz
- repaired no-return-in-nonvoid-function
  (noreturn.patch)
* Mon Apr 28 2008 pgajdos@suse.cz
- repaired build for
  * ia64 (%%ifarch in hdf5.spec)
  * s390, s390x (s390.patch)
* Tue Mar 25 2008 pgajdos@suse.cz
- package moved from BS, project science
- needed by octave 3.0
